@@ -1,5 +1,5 @@
 /* makeinfo.h -- declarations for Makeinfo.
-   $Id: makeinfo.h,v 1.27 2007/07/01 21:20:33 karl Exp $
+   $Id: makeinfo.h,v 1.30 2007/09/15 23:48:45 karl Exp $
 
    Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004,
    2005, 2006, 2007 Free Software Foundation, Inc.
@@ -133,9 +133,9 @@ DECLARE (int, xml, 0);
 /* Nonzero means that we're generating DocBook. (--docbook) */
 DECLARE (int, docbook, 0);
 
-/* Nonzero means true 8-bit output for Info and plain text.
-   (--enable-encoding) */
-DECLARE (int, enable_encoding, 0);
+/* Nonzero means 8-bit output for Info and plain text, according to
+   @documentencoding.  (--enable-encoding) */
+DECLARE (int, enable_encoding, 1);
 
 /* Nonzero means escape characters in HTML output. */
 DECLARE (int, escape_html, 1);
@@ -223,10 +223,6 @@ DECLARE (int, process_tex, 0);
 /* Nonzero means that we process @xml and @ifxml.  (--ifxml) */
 DECLARE (int, process_xml, 0);
 
-/* Maximum number of references to a single node before complaining.
-   (--reference-limit) */
-DECLARE (int, reference_warning_limit, 1000);
-
 /* Default is to check node references.  (--no-validate) */
 DECLARE (int, validating, 1);
 
@@ -322,10 +318,10 @@ typedef struct generic_list {
   struct generic_list *next;
 } GENERIC_LIST;
 
-/* Use __ instead of _ to translate strings that end up in the output
-   document.  */
+/* Use `gdt' instead of `_' to translate strings that end up in the
+   output document.  */
 extern char *getdocumenttext (const char *msgid);
-#define __(s) getdocumenttext(s)
+#define gdt(s) getdocumenttext(s)
 
 /* Reverse the order of a list.  */
 extern GENERIC_LIST * reverse_list (GENERIC_LIST *list);
